@@ -2,7 +2,7 @@ from django.conf.urls import patterns, url
 from two_factor.views import (LoginView,
                               PhoneDeleteView, PhoneSetupView, DisableView,
                               BackupTokensView, SetupCompleteView, SetupView,
-                              ProfileView)
+                              ProfileView, QRGeneratorView)
 
 
 core = patterns(
@@ -17,6 +17,11 @@ core = patterns(
         view=SetupView.as_view(),
         name='setup',
     ),
+    url(
+        regex=r'^account/two_factor/qrcode$',
+        view=QRGeneratorView.as_view(),
+        name='qr',
+    ),
     url(
         regex=r'^account/two_factor/setup/complete/$',
         view=SetupCompleteView.as_view(),
